#ifndef NT2_INCLUDE_CONSTANTS_TWOTOM10_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_TWOTOM10_HPP_INCLUDED

#include <nt2/constant/include/constants/twotom10.hpp>

#endif
